import {
  ApplicationContext,
  Catch,
  IMidwayContainer,
  Inject,
} from '@midwayjs/core';
import { Context } from '@midwayjs/koa';
import { ServiceError } from '../error/service.error';
import { MidwayI18nService } from '@midwayjs/i18n';

// 指定那些异常来这里处理
@Catch([ServiceError])
export class CustomErrorFilter {
  @Inject()
  ctx: Context;
  @ApplicationContext()
  applicationContext: IMidwayContainer;
  async catch(err: Error, ctx: Context) {
    const i18n = await this.applicationContext.getAsync(MidwayI18nService);
    const errmsg = i18n.translate(err.message, {
      locale: ctx.locale,
      // 需要全小写
      group: 'error',
    });
    const result: any = {
      errcode: err.message,
      errmsg,
    };
    return result;
  }
}
